@@ -14,12 +14,11 @@
 #    under the License.
 
 import datetime
+from unittest import mock
 import warnings
 
 import iso8601
-import mock
 import netaddr
-import six
 import testtools
 
 from oslo_versionedobjects import _utils
@@ -159,8 +158,6 @@ class TestString(TestField):
         self.field = fields.StringField()
         self.coerce_good_values = [
             ('foo', 'foo'), (1, '1'), (1.0, '1.0'), (True, 'True')]
-        if six.PY2:
-            self.coerce_good_values += [(long(1), '1')]  # noqa
         self.coerce_bad_values = [None]
         self.to_primitive_values = self.coerce_good_values[0:1]
         self.from_primitive_values = self.coerce_good_values[0:1]
@@ -1061,7 +1058,7 @@ class TestObject(TestField):
         ex = self.assertRaises(ValueError, self.field.coerce,
                                'obj', 'attr', [{}])
         self.assertEqual('An object of type TestableObject is required '
-                         'in field attr, not a list', six.text_type(ex))
+                         'in field attr, not a list', str(ex))
 
     def test_get_schema(self):
         self.assertEqual(
@@ -1229,3 +1226,41 @@ class TestIPV6Network(TestField):
         invalid_vals = [x for x in self.coerce_bad_values]
         for invalid_val in invalid_vals:
             self.assertNotRegex(str(invalid_val), pattern)
+
+
+class FakeCounter(object):
+    def __init__(self):
+        self.n = 0
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        if self.n <= 4:
+            self.n += 1
+            return self.n
+        else:
+            raise StopIteration
+
+
+class TestListTypes(test.TestCase):
+
+    def test_regular_list(self):
+        fields.List(fields.Integer).coerce(None, None, [1, 2])
+
+    def test_non_iterable(self):
+        self.assertRaises(ValueError,
+                          fields.List(fields.Integer).coerce, None, None, 2)
+
+    def test_string_iterable(self):
+        self.assertRaises(ValueError,
+                          fields.List(fields.Integer).coerce, None, None,
+                          'hello')
+
+    def test_mapping_iterable(self):
+        self.assertRaises(ValueError,
+                          fields.List(fields.Integer).coerce, None, None,
+                          {'a': 1, 'b': 2})
+
+    def test_iter_class(self):
+        fields.List(fields.Integer).coerce(None, None, FakeCounter())
